@@ -1,16 +1,17 @@
 //! JSON-RPC request methods
 
+use crate::prelude::*;
 use crate::Error;
-use serde::{de::Error as _, Deserialize, Deserializer, Serialize, Serializer};
-use std::{
+use core::{
     fmt::{self, Display},
     str::FromStr,
 };
+use serde::{de::Error as _, Deserialize, Deserializer, Serialize, Serializer};
 
 /// JSON-RPC request methods.
 ///
 /// Serialized as the "method" field of JSON-RPC/HTTP requests.
-#[derive(Copy, Clone, Debug, Hash, Eq, PartialEq)]
+#[derive(Copy, Clone, Debug, Hash, Eq, PartialEq, Ord, PartialOrd)]
 pub enum Method {
     /// Get ABCI info
     AbciInfo,
@@ -24,6 +25,9 @@ pub enum Method {
     /// Get ABCI results for a particular block
     BlockResults,
 
+    /// Search for blocks by their BeginBlock and EndBlock events
+    BlockSearch,
+
     /// Get blockchain info
     Blockchain,
 
@@ -84,6 +88,7 @@ impl Method {
             Method::AbciQuery => "abci_query",
             Method::Block => "block",
             Method::BlockResults => "block_results",
+            Method::BlockSearch => "block_search",
             Method::Blockchain => "blockchain",
             Method::BroadcastEvidence => "broadcast_evidence",
             Method::BroadcastTxAsync => "broadcast_tx_async",
@@ -114,6 +119,7 @@ impl FromStr for Method {
             "abci_query" => Method::AbciQuery,
             "block" => Method::Block,
             "block_results" => Method::BlockResults,
+            "block_search" => Method::BlockSearch,
             "blockchain" => Method::Blockchain,
             "broadcast_evidence" => Method::BroadcastEvidence,
             "broadcast_tx_async" => Method::BroadcastTxAsync,
